==> libguestfs_1.27.46.orig.tar.gz: libguestfs-1.27.46/tests/qemu/qemu-force-tcg.sh <==
#!/bin/bash -
# libguestfs
# Copyright (C) 2014 Red Hat Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# Check force_tcg really forces TCG mode.

if [ -n "$SKIP_QEMU_FORCE_TCG_SH" ]; then
    echo "$0: test skipped because environment variable is set."
    exit 77
fi

# Only applicable to the direct and libvirt backends:
if [ "$(../../fish/guestfish get-backend)" = "uml" ]; then
    echo "$0: skipping test because it is only applicable when qemu is being used."
    exit 77
fi

set -e

rm -f qemu-force-tcg.out

../../fish/guestfish -a /dev/null <<EOF
set-backend-setting force_tcg 1
run
debug sh "cat /sys/devices/system/clocksource/clocksource0/current_clocksource" | cat > qemu-force-tcg.out
EOF

# The output file should *not* contain kvm-clock.
if [ "$(cat qemu-force-tcg.out)" = "kvm-clock" ]; then
    echo "$0: force_tcg setting did not force TCG mode"
    cat qemu-force-tcg.out
    exit 1
fi

rm qemu-force-tcg.out

==> libguestfs_1.29.5.orig.tar.gz: libguestfs-1.29.5/tests/qemu/qemu-force-tcg.sh <==
#!/bin/bash -
# libguestfs
# Copyright (C) 2014 Red Hat Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# Check force_tcg really forces TCG mode.

if [ -n "$SKIP_QEMU_FORCE_TCG_SH" ]; then
    echo "$0: test skipped because environment variable is set."
    exit 77
fi

# Only applicable to the direct and libvirt backends:
if [ "$(guestfish get-backend)" = "uml" ]; then
    echo "$0: skipping test because it is only applicable when qemu is being used."
    exit 77
fi

set -e

rm -f qemu-force-tcg.out

guestfish -a /dev/null <<EOF
set-backend-setting force_tcg 1
run
debug sh "cat /sys/devices/system/clocksource/clocksource0/current_clocksource" | cat > qemu-force-tcg.out
EOF

# The output file should *not* contain kvm-clock.
if [ "$(cat qemu-force-tcg.out)" = "kvm-clock" ]; then
    echo "$0: force_tcg setting did not force TCG mode"
    cat qemu-force-tcg.out
    exit 1
fi

rm qemu-force-tcg.out
